==> tinyerp-3.0.3.tar.gz: 3.0.3/server/bin/addons/account/wizard/wizard_refund.py <==
##############################################################################
#
# Copyright (c) 2004 TINY SPRL. (http://tiny.be) All Rights Reserved.
#                    Fabien Pinckaers <fp@tiny.Be>
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import time

import wizard
import netsvc

def _invoice_refund(self, uid, datas):
	service = netsvc.LocalService("object_proxy")
	invoice = service.execute(uid, 'account.invoice', 'read', [datas['id']], ['name', 'type', 'number', 'reference', 'project_id', 'comment', 'date_due', 'partner_id', 'address_contact_id', 'address_invoice_id', 'partner_contact', 'partner_insite', 'partner_ref', 'payment_term', 'account_id','invoice_line','tax_line'])[0]
		
	del invoice['id']

	invoice_type_map = {
		'out_invoice': 'out_refund',
		'in_invoice': 'in_refund',
		'out_refund': 'out_invoice',
		'in_refund': 'in_invoice'
	}

	invoice['type'] = invoice_type_map.get(invoice['type'], False)
	invoice['date_invoice'] = time.strftime('%Y-%m-%d')
	invoice['state'] = 'draft'
	invoice['number'] = False
	
	for field in ('address_contact_id','address_invoice_id','partner_id','project_id','account_id'):
		invoice[field] = invoice[field] and invoice[field][0]

	line_ids = invoice['invoice_line']
	del invoice['invoice_line']
	
	tax_ids = invoice['tax_line']
	del invoice['tax_line']
		
	# create the new invoice
	invoice_id = service.execute(uid, 'account.invoice', 'create', invoice)
	
	# duplicate the invoice lines
	lines = service.execute(uid, 'account.invoice.line', 'read', line_ids)
	for line in lines:
		del line['id']
		line['invoice_id'] = invoice_id
		line['account_id'] = line['account_id'] and line['account_id'][0]
		service.execute(uid, 'account.invoice.line', 'create', line)

	# duplicate the tax lines (manual taxes only)
	tax_lines = service.execute(uid, 'account.invoice.tax', 'read', tax_ids)
	for line in tax_lines:
		if line['manual']:
			del line['id']
			line['invoice_id'] = invoice_id
			line['account_id'] = line['account_id'] and line['account_id'][0]
			service.execute(uid, 'account.invoice.tax', 'create', line)

	return {}

class wiz_refund(wizard.interface):
	states = {
		'init': {
			'actions': [_invoice_refund],
			'result': {'type': 'state', 'state':'end'}
		}
	}
wiz_refund('account.invoice.refund')

==> tinyerp-3.4.0-rc1.tar.gz: 3.4.0-rc1/server/bin/addons/account/wizard/wizard_refund.py <==
##############################################################################
#
# Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import wizard
import netsvc

sur_form = '''<?xml version="1.0"?>
<form string="Refund Invoice">
	<label string="Are you sure you want to refund this invoice ?"/>
</form>'''

sur_fields = {
}

class wiz_refund(wizard.interface):
	def _invoice_refund(self, cr, uid, data, context):
		service = netsvc.LocalService("object_proxy")
		service.execute(uid, 'account.invoice', 'refund', [data['id']])
		return {}
		
	states = {
		'init': {
			'actions': [],
			'result': {'type':'form', 'arch':sur_form, 'fields':sur_fields, 'state':[('end','Cancel'),('refund','Refund Invoice')]}
		},
		'refund': {
			'actions': [_invoice_refund],
			'result': {'type':'state', 'state':'end'}
		}
	}
wiz_refund('account.invoice.refund')
